pub struct ContainerBuilder { /* private fields */ }Expand description
Builder for the Container.
You should not use this directly, but use the Container::builder method instead.
By default this container is the same as running this:
let builder = Container::builder()
.with_image_tag("latest")
.with_port(3000)
.with_api_token("secret");Implementations
Sourceimpl ContainerBuilder
impl ContainerBuilder
Sourcepub fn with_image_tag(self, tag: &str) -> Self
pub fn with_image_tag(self, tag: &str) -> Self
Set the image tag to use for the container.
Sourcepub fn with_api_token(self, token: &str) -> Self
pub fn with_api_token(self, token: &str) -> Self
Set the API token to use for the container.
Sourcepub fn with_port(self, port: impl Into<ContainerPort>) -> Self
pub fn with_port(self, port: impl Into<ContainerPort>) -> Self
Set the port to use for the container.
This is the port that will be exposed from the container to the host.
It will be mapped to a random port on the host that you can connect to.
To find that port, use the Container::get_mapped_port method.
Sourcepub fn with_signing_key(self) -> Self
pub fn with_signing_key(self) -> Self
Enable signing of events with a generated key pair.
This will generate a new key pair for signing events and configure the database to use it. The private key will be used to sign events and the public key will be used to verify them.
Sourcepub async fn start(self) -> Result<Container, ContainerError>
pub async fn start(self) -> Result<Container, ContainerError>
Start the test container.
This call will transform the builder into a running container. It takes care of starting the container and waiting for it to be ready by waiting for the ping endpoint to respond since that doesn’t require authentication.
Errors
This function will return an error if the container could not be started.